==> aptitude_0.6.11.orig.tar.xz: aptitude-0.6.11/src/cmdline/cmdline_changelog.h <==
// cmdline_changelog.h                        -*-c++-*-
//
// Copyright (C) 2004, 2010 Daniel Burrows
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#ifndef CMDLINE_CHANGELOG_H
#define CMDLINE_CHANGELOG_H

// System includes:
#include <boost/shared_ptr.hpp>

#include <string>
#include <vector>

/** \file cmdline_changelog.h
 */

namespace aptitude
{
  namespace cmdline
  {
    class terminal_metrics;
  }
}

/** \brief Display the changelog of each of the given package specifiers.
 *
 *  The specifiers are literal package names, with optional version/archive
 *  descriptors.  DumpErrors() is called after each changelog is displayed.
 */
void do_cmdline_changelog(const std::vector<std::string> &packages,
                          const boost::shared_ptr<aptitude::cmdline::terminal_metrics> &term_metrics);

int cmdline_changelog(int argc, char *argv[]);

#endif // CMDLINE_CHANGELOG_H

==> aptitude_0.7.4.orig.tar.xz: aptitude-0.7.4/src/cmdline/cmdline_changelog.h <==
// cmdline_changelog.h                        -*-c++-*-
//
// Copyright (C) 2004, 2010 Daniel Burrows
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#ifndef CMDLINE_CHANGELOG_H
#define CMDLINE_CHANGELOG_H

#include <memory>
#include <string>
#include <vector>

/** \file cmdline_changelog.h
 */

namespace aptitude
{
  namespace cmdline
  {
    class terminal_metrics;
  }
}

/** \brief Display the changelog of each of the given package specifiers.
 *
 *  The specifiers are literal package names, with optional version/archive
 *  descriptors.  DumpErrors() is called after each changelog is displayed.
 */
void do_cmdline_changelog(const std::vector<std::string> &packages,
                          const std::shared_ptr<aptitude::cmdline::terminal_metrics> &term_metrics);

int cmdline_changelog(int argc, char *argv[]);

#endif // CMDLINE_CHANGELOG_H
